<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="zh_CN">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>应用代理</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理类型</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>选填</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>配置好代理后，可在启动器的应用右键菜单查看“使用代理”选项，勾选后即可使用代理</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>保 存</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>无效的端口</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>断开连接</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>删 除</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>保 存</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在连接</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>断开连接</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>您确定要删除当前配置吗？</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>有线连接 %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>热点</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>无线连接 %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE连接 %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>新建VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN类型</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>导 出</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>应用代理</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>个人热点</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>网络详情</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>系统代理</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有线网络</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>飞行模式</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>有线网卡</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>添加网络设置</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>无线网卡</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>连接到隐藏网络</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>创建PPPoE连接</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN状态</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>添加VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>导入VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理类型</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>配置URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>热点</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>添加热点</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>接口</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>频段</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>首选DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子网掩码</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前缀</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>速率</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飞行模式</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>打开飞行模式将关闭无线网络、个人热点和蓝牙功能</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>无效的DNS地址</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>以太网</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>不指定设备</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>设备MAC地址</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>克隆MAC地址</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>自定义MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>通用</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>通用</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>名称已被占用</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>自动连接</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>热点</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>添加设置</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>添加热点</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IP地址重复</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>无效的子网掩码</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>只允许一个网关</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子网掩码</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IP地址重复</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>只允许一个网关</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前缀</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>仅用于相对应的网络上的资源</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子网掩码</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前缀</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>无效的子网掩码</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP地址冲突</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>网络详情</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>系统代理</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>应用代理</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>飞行模式</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>网络详情</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP地址冲突</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>用网络管理器配置</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>个人热点</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>拨号</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>服务</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒绝EAP认证</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒绝PAP认证</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒绝CHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒绝MSCHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒绝MSCHAPv2认证</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>无BSD数据压缩</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>无Deflate数据压缩</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>无TCP头压缩</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>无协议字段压缩</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>无地址/控制压缩</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>发送PPP回响包</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用MPPE点到点加密</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>使用128位MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>使用带状态的MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>创建PPPoE连接</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>系统代理</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>保 存</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理类型</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>选填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP代理</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS代理</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP代理</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS代理</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>忽略以上主机和域的代理配置</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>配置URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>隧道TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>受保护的EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>仅为该用户存储密码</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>存储所有用户密码</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>总是询问</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>匿名</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>已认证</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>兼有</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>版本0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>版本1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP认证</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>身份</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密码选项</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私钥</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA证书</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户证书</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>匿名身份</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>自动PAC配置</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC文件</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>内部认证</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP版本</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私钥密码</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>密码无效</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2个人版</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3个人版</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>密钥</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>安全</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>密码无效</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2个人版</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2企业版</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3个人版</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>共享密钥</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>开放式系统</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>安全认证类型</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>密钥</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN高级选项</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>自定义网关端口</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>网关端口</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>自定义重新协商间隔</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>重新协商间隔</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>使用LZO压缩</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>使用TCP连接</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>使用TAP设备</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>自定义最大传输单元(MTU)</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>自定义UDP数据报段长度</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP数据报段长度</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>限制隧道TCP最大段长度(MSS)</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>随机远程主机</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN高级选项</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>思科（默认）</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>网屏</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>安全（默认）</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>弱</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T若可用（默认）</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>总是NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>思科UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2（默认）</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>服务器（默认）</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>域</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>供应商</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT遍历</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH 组</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>前向保密</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>本地端口</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>禁用死端检测</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>启用IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>组名</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>组ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>预共享密钥</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>密钥交换协议</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>安全封装协议</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA证书</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>代理</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>允许思科安全桌面木马</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD 脚本</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户证书</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私钥</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>为密钥口令句使用FSID</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>证书（TLS）</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>证书和密码（TLS）</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>静态密钥</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已保存的</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>总是询问</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>不要求</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>认证类型</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA证书</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户证书</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私钥</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密码选项</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私钥密码</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>自定义密钥方向</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>密钥方向</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>远程IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>本地IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>都可用（默认）</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40位（较安全）</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128位（最安全）</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒绝EAP认证</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒绝PAP认证</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒绝CHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒绝MSCHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒绝MSCHAPv2认证</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>无BSD数据压缩</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>无Deflate数据压缩</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>无TCP头压缩</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>无协议字段压缩</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>无地址/控制压缩</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>发送PPP回响包</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用MPPE点到点加密</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>使用带状态的MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN状态</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>添加VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>导入VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>导入错误</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>导入文件错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN代理</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>不要求</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理类型</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>服务器地址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>失败时重试</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA文件</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>忽略证书警告</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>使用TLS主机名扩展</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN安全</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC认证</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已保存的</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>总是询问</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>不要求</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密码选项</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT域</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN代理</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>服务器地址</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私钥</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH代理</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>智能卡</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>预共享密钥</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA证书</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>认证类型</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户证书</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>请求内部IP地址</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>强制使用UDP封装</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>使用IP压缩 </translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>启用自定义加密方案</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS 认证</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>客户端</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>服务器</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>主题匹配</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>远程证书类型</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>密钥文件</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>自定义密钥方向</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>密钥方向</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已保存的</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>总是询问</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>不要求</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密码选项</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>组名</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>组密码</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>使用混合认证</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA文件</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>请您先插入网线！</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>有线网卡</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>添加网络设置</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>选择设置</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>无线网卡</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>关闭热点</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>若要连接并使用无线网络功能，请先关闭热点分享</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>连接到隐藏网络</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>不指定设备</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>设备MAC地址</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>自定义MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>